@@ -276,15 +276,9 @@ class TransformerTask:
         return results
 
     def single_predict(self, example: InputExample):
-        input_ids = torch.tensor(self._taskModel.tokenizer.encode_plus(
-            (example.text_a, example.text_b),
-            max_length=self.task_args.data_args.max_seq_length,
-            pad_to_max_length=True
-        )).unsqueeze(0)  # Batch size 1
-
-        input_ids.to(self.task_args.training_args.device)
-
-        return self._taskModel.model(input_ids)[0]
+        data_processor = DataProcessor()
+        data_processor.get_dev_examples = lambda s: [example]
+        return self.predict(data_processor)
 
     def predict(self, data_processor=None) -> PredictionOutput:
         dataset = TaskDataset(self.task_args.data_args,
